"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitOne = exports.emitMany = void 0;
const Keywords = require("../tokens/keywords");
const Delimiters = require("../tokens/delimiters");
const GenericTokens = require("../tokens/generic_tokens");
const ScopeTokens = require("../tokens/scope_tokens");
const TypeReferenceTokens = require("../tokens/type_reference_tokens");
const TypeEmitter = require("./type_emitter");
function emitMany(writer, classes, isFirst) {
    if (classes == null || classes.length === 0)
        return;
    if (!isFirst)
        writer.writeLine();
    classes.forEach((c, i, arr) => emitOne(writer, c, i === arr.length - 1));
}
exports.emitMany = emitMany;
function emitOne(writer, _class, isLast) {
    TypeEmitter.emitAttributes(writer, _class.attributes);
    emitDefinition(writer, _class);
    TypeEmitter.emitFields(writer, _class.fields);
    TypeEmitter.emitProperties(writer, _class.properties, _class.fields);
    TypeEmitter.emitMethods(writer, _class.methods, _class.properties);
    TypeEmitter.emitEnd(writer, isLast);
}
exports.emitOne = emitOne;
function emitDefinition(writer, _class) {
    const { access, isNew, isPartial, modifier, name, generics, baseClass } = _class;
    const accessTokens = access ? [access, Delimiters.space] : [];
    const newTokens = isNew ? [Keywords._new, Delimiters.space] : [];
    const modifierTokens = modifier ? [modifier, Delimiters.space] : [];
    const partialTokens = isPartial ? [Keywords.partial, Delimiters.space] : [];
    const genericTokens = GenericTokens.emit(generics);
    const baseClassTokens = baseClass ? TypeReferenceTokens.emit(baseClass) : [];
    const extensionTokens = baseClassTokens.length ? [Delimiters.space, Delimiters.colon, Delimiters.space, ...baseClassTokens] : [];
    writer
        .outputTabs()
        .write(...accessTokens)
        .write(...newTokens)
        .write(...modifierTokens)
        .write(...partialTokens)
        .write(Keywords._class, Delimiters.space, name)
        .write(...genericTokens)
        .write(...extensionTokens)
        .writeLineNoTabs()
        .writeLine(ScopeTokens.open)
        .indent();
}
