"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const Keywords = require("../tokens/keywords");
const Delimiters = require("../tokens/delimiters");
const GenericTokens = require("../tokens/generic_tokens");
const CurlyBraces = require("../tokens/curly_braces");
const TypeReferenceTokens = require("../tokens/type_reference_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
const AttributeEmitter = require("./attribute_emitter");
const MemberEmitter = require("./member_emitter");
function emit(writer, _class) {
    AttributeEmitter.emitMany(writer, _class.attributes);
    emitDefinition(writer, _class);
    MemberEmitter.emitMany(writer, _class.name, _class.members);
    emitEnd(writer);
}
exports.emit = emit;
function emitDefinition(writer, _class) {
    const { access, isNew, isPartial, modifier, name, generics, baseType } = _class;
    const baseTypeTokens = baseType ? TypeReferenceTokens.emit(baseType) : [];
    const extensionTokens = baseTypeTokens.length ? [Delimiters.space, Delimiters.colon, Delimiters.space, ...baseTypeTokens] : [];
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forNew(isNew))
        .write(...ModifierTokens.forModifier(modifier))
        .write(...ModifierTokens.forPartial(isPartial))
        .write(Keywords._class, Delimiters.space, name)
        .write(...GenericTokens.emit(generics))
        .write(...extensionTokens)
        .writeLineNoTabs()
        .writeLine(CurlyBraces.open)
        .indent();
}
function emitEnd(writer) {
    writer
        .unindent()
        .writeLine(CurlyBraces.close);
}
