"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const CurlyBraces = require("../tokens/curly_braces");
const MethodParameterTokens = require("../tokens/method_parameter_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
function emit(writer, typeName, constructor) {
    emitDefinition(writer, typeName, constructor);
    emitBody(writer, constructor);
    emitEnd(writer);
}
exports.emit = emit;
function emitDefinition(writer, typeName, constructor) {
    const { access, isStatic, parameters } = constructor;
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forStatic(isStatic))
        .write(typeName)
        .write(...MethodParameterTokens.emit(parameters))
        .writeLineNoTabs()
        .writeLine(CurlyBraces.open)
        .indent();
}
function emitBody(writer, constructor) {
    const { body } = constructor;
    body.statements.forEach(s => writer.writeLine(s));
}
function emitEnd(writer) {
    writer
        .unindent()
        .writeLine(CurlyBraces.close);
}
