"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitOne = exports.emitMany = void 0;
const ArrayUtils = require("../utils/array_utils");
const FieldEmitter = require("./field_emitter");
const PropertyEmitter = require("./property_emitter");
const ConstructorEmitter = require("./constructor_emitter");
const MethodEmitter = require("./method_emitter");
const TypeEmitter = require("./type_emitter");
function emitMany(writer, typeName, members) {
    if (ArrayUtils.isFalsy(members))
        return;
    members.forEach((x, i, arr) => emitOne(writer, typeName, x, i === arr.length - 1));
}
exports.emitMany = emitMany;
function emitOne(writer, typeName, member, isLast) {
    switch (member.kind) {
        case "field":
            FieldEmitter.emit(writer, member);
            break;
        case "property":
            PropertyEmitter.emit(writer, member);
            break;
        case "constructor":
            ConstructorEmitter.emit(writer, typeName, member);
            break;
        case "method":
            MethodEmitter.emit(writer, member);
            break;
        case "type":
            TypeEmitter.emitOne(writer, member.type);
            break;
        default:
            throw new Error(`Not supported type ${JSON.stringify(member, null, 4)}`);
    }
    if (!isLast)
        writer.writeLine();
}
exports.emitOne = emitOne;
