"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const Delimiters = require("../tokens/delimiters");
const CurlyBraces = require("../tokens/curly_braces");
const GenericTokens = require("../tokens/generic_tokens");
const TypeReferenceTokens = require("../tokens/type_reference_tokens");
const MethodParameterTokens = require("../tokens/method_parameter_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
function emit(writer, method) {
    emitDefinition(writer, method);
    emitBody(writer, method);
    emitEnd(writer);
}
exports.emit = emit;
function emitDefinition(writer, method) {
    const { access, modifier, result, name, generics, parameters } = method;
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forModifier(modifier))
        .write(...TypeReferenceTokens.emit(result))
        .write(Delimiters.space)
        .write(name)
        .write(...GenericTokens.emit(generics))
        .write(...MethodParameterTokens.emit(parameters))
        .writeLineNoTabs()
        .writeLine(CurlyBraces.open)
        .indent();
}
function emitBody(writer, method) {
    const { body } = method;
    body.statements.forEach(s => writer.writeLine(s));
}
function emitEnd(writer) {
    writer
        .unindent()
        .writeLine(CurlyBraces.close);
}
