"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const Signs = require("../tokens/signs");
const Delimiters = require("../tokens/delimiters");
const CurlyBraces = require("../tokens/curly_braces");
const PropertyTokens = require("../tokens/property_tokens");
const TypeReferenceTokens = require("../tokens/type_reference_tokens");
const ModifierTokens = require("../tokens/modifier_tokens");
const AttributeEmitter = require("./attribute_emitter");
function emit(writer, property) {
    const { access, type, name, value } = property;
    const valueTokens = value != null ? [Delimiters.space, Signs.equal, Delimiters.space, value, Delimiters.semicolon] : [];
    emitAttributes(writer, property);
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...TypeReferenceTokens.emit(type))
        .write(Delimiters.space)
        .write(name)
        .write(Delimiters.space)
        .write(...emitBody())
        .write(...valueTokens)
        .writeLineNoTabs();
}
exports.emit = emit;
function emitAttributes(writer, property) {
    const { attributes } = property;
    AttributeEmitter.emitMany(writer, attributes);
}
function emitBody() {
    return [
        CurlyBraces.open, Delimiters.space,
        ...emitGetter(), Delimiters.space,
        ...emitterSetter(), Delimiters.space,
        CurlyBraces.close
    ];
}
function emitGetter() {
    return [PropertyTokens.get, Delimiters.semicolon];
}
function emitterSetter() {
    return [PropertyTokens.set, Delimiters.semicolon];
}
