"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitOne = exports.emitMany = void 0;
const Keywords = require("../tokens/keywords");
const Delimiters = require("../tokens/delimiters");
const GenericTokens = require("../tokens/generic_tokens");
const ScopeTokens = require("../tokens/scope_tokens");
const TypeEmitter = require("./type_emitter");
function emitMany(writer, structs) {
    if (structs == null || structs.length === 0)
        return;
    structs.forEach((s, i, arr) => emitOne(writer, s, i === arr.length - 1));
}
exports.emitMany = emitMany;
function emitOne(writer, struct, isLast) {
    TypeEmitter.emitAttributes(writer, struct.attributes);
    emitDefinition(writer, struct);
    TypeEmitter.emitFields(writer, struct.fields);
    TypeEmitter.emitProperties(writer, struct.properties, struct.fields);
    TypeEmitter.emitMethods(writer, struct.methods, struct.properties);
    TypeEmitter.emitEnd(writer, isLast);
}
exports.emitOne = emitOne;
function emitDefinition(writer, struct) {
    const { access, isNew, isPartial, name, generics } = struct;
    const accessTokens = access ? [access, Delimiters.space] : [];
    const newTokens = isNew ? [Keywords._new, Delimiters.space] : [];
    const partialTokens = isPartial ? [Keywords.partial, Delimiters.space] : [];
    const genericTokens = GenericTokens.emit(generics);
    writer
        .outputTabs()
        .write(...accessTokens)
        .write(...newTokens)
        .write(...partialTokens)
        .write(Keywords.struct, Delimiters.space, name)
        .write(...genericTokens)
        .writeLineNoTabs()
        .writeLine(ScopeTokens.open)
        .indent();
}
