"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const Keywords = require("../tokens/keywords");
const Delimiters = require("../tokens/delimiters");
const GenericTokens = require("../tokens/generic_tokens");
const CurlyBraces = require("../tokens/curly_braces");
const ModifierTokens = require("../tokens/modifier_tokens");
const AttributeEmitter = require("./attribute_emitter");
const MemberEmitter = require("./member_emitter");
function emit(writer, struct) {
    AttributeEmitter.emitMany(writer, struct.attributes);
    emitDefinition(writer, struct);
    MemberEmitter.emitMany(writer, struct.name, struct.members);
    emitEnd(writer);
}
exports.emit = emit;
function emitDefinition(writer, struct) {
    const { access, isNew, isPartial, name, generics } = struct;
    writer
        .outputTabs()
        .write(...ModifierTokens.forAccess(access))
        .write(...ModifierTokens.forNew(isNew))
        .write(...ModifierTokens.forPartial(isPartial))
        .write(Keywords.struct, Delimiters.space, name)
        .write(...GenericTokens.emit(generics))
        .writeLineNoTabs()
        .writeLine(CurlyBraces.open)
        .indent();
}
function emitEnd(writer) {
    writer
        .unindent()
        .writeLine(CurlyBraces.close);
}
