"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitOne = exports.emitMany = void 0;
const ArrayUtils = require("../utils/array_utils");
const ClassTypeEmitter = require("./class_type_emitter");
const StructTypeEmitter = require("./struct_type_emitter");
const EnumTypeEmitter = require("./enum_type_emitter");
const InterfaceTypeEmitter = require("./interface_type_emitter");
const DelegateTypeEmitter = require("./delegate_type_emitter");
function emitMany(writer, types) {
    if (ArrayUtils.isFalsy(types))
        return;
    types.forEach((x, i, arr) => emitOne(writer, x, i === arr.length - 1));
}
exports.emitMany = emitMany;
function emitOne(writer, type, isLast) {
    switch (type.kind) {
        case "class":
            ClassTypeEmitter.emit(writer, type);
            break;
        case "struct":
            StructTypeEmitter.emit(writer, type);
            break;
        case "enum":
            EnumTypeEmitter.emit(writer, type);
            break;
        case "interface":
            InterfaceTypeEmitter.emit(writer, type);
            break;
        case "delegate":
            DelegateTypeEmitter.emit(writer, type);
            break;
        default:
            throw new Error(`Not supported type ${JSON.stringify(type, null, 4)}`);
    }
    if (!isLast)
        writer.writeLine();
}
exports.emitOne = emitOne;
