"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emit = void 0;
const ArrayUtils = require("../utils/array_utils");
const Delimiters = require("./delimiters");
const AngleBrackets = require("./angle_brackets");
const TypeReferenceTokens = require("./type_reference_tokens");
function emit(generics) {
    if (ArrayUtils.isFalsy(generics))
        return ArrayUtils.empty();
    else
        return AngleBrackets.enclose(precursors(generics));
}
exports.emit = emit;
function precursors(generics) {
    return generics
        .map(g => precursor(g))
        .flatMap((g, i, arr) => i === arr.length - 1 ? g : [...g, Delimiters.comma, Delimiters.space]);
}
function precursor(generic) {
    switch (generic.kind) {
        case "argument": return precursorArgument(generic);
        case "parameter": return precursorParameter(generic);
        default: throw new Error(`Invalid generic`);
    }
}
function precursorParameter(genericParameter) {
    const { modifier, name } = genericParameter;
    const modifierTokens = modifier ? [modifier, Delimiters.space] : [];
    return [...modifierTokens, name];
}
function precursorArgument(genericArgument) {
    const { type } = genericArgument;
    return [...TypeReferenceTokens.emit(type)];
}
