/**
 * Provides a text writer that can indent new lines by a tab string token.
 */
export declare class IndentedStringWriter {
    private _buffer;
    private _indentSize;
    private _indentLevel;
    private _offset;
    private _eol;
    /**
     * Gets the current indent level.
     */
    private get indentLevel();
    /**
     * Sets the current indent level.
     */
    private set indentLevel(value);
    /**
     * Gets the inner buffer array.
     */
    get buffer(): readonly string[];
    /**
     * Creates an instance of the IndentedStringWriter class.
     * @param indentSize the initial indent size in spaces.
     */
    constructor(indentSize?: number);
    /**
     * Puts the tab string according to the indent level.
     */
    outputTabs(): this;
    /**
     * Writes the specified string values followed by a line terminator, to the buffer.
     * @param values The string values to write.
     */
    writeLine(...values: string[]): this;
    /**
     * Writes the specified string values followed by a line terminator without tabs, to the buffer.
     * @param values The string values to write.
     */
    writeLineNoTabs(...values: string[]): this;
    /**
     * Writes the specified string values to the buffer.
     * @param values The string values to write.
     */
    write(...values: string[]): this;
    /**
     * Increases the indent level.
     */
    indent(): this;
    /**
     * Decreases the indent level.
     */
    unindent(): this;
    /**
     * Generate a string representation of the writer inner buffer.
     */
    toString(): string;
}
